@@ -23,6 +23,7 @@ import os.path
 import shutil
 import sys
 import re
+import unicodedata
 import traceback
 from PyQt4 import QtCore
 from picard.mbxml import artist_credit_from_node
@@ -73,15 +74,8 @@ class File(LockableObject, Item):
 
         self.orig_metadata = Metadata()
         self.user_metadata = Metadata()
-        self.server_metadata = Metadata()
-        self.saved_metadata = self.server_metadata
         self.metadata = self.user_metadata
 
-        self.orig_metadata['title'] = os.path.basename(self.filename)
-
-        self.user_metadata.copy(self.orig_metadata)
-        self.server_metadata.copy(self.orig_metadata)
-
         self.similarity = 1.0
         self.parent = None
 
@@ -115,7 +109,7 @@ class File(LockableObject, Item):
         return self
 
     def _copy_metadata(self, metadata):
-        filename, extension = os.path.splitext(os.path.basename(self.filename))
+        filename, extension = os.path.splitext(self.base_filename)
         self.metadata.copy(metadata)
         self.metadata['~extension'] = extension[1:].lower()
         if 'title' not in self.metadata:
@@ -178,6 +172,7 @@ class File(LockableObject, Item):
             self.set_state(File.ERROR, update=True)
         else:
             self.filename = new_filename = result
+            self.base_filename = os.path.basename(new_filename)
             length = self.orig_metadata.length
             temp_info = {}
             for info in ('~#bitrate', '~#sample_rate', '~#channels',
@@ -242,6 +237,9 @@ class File(LockableObject, Item):
                 new_filename = new_filename.replace('/.', '/_').replace('\\.', '\\_')
                 if new_filename[0] == '.':
                     new_filename = '_' + new_filename[1:]
+                # Fix for precomposed characters on OSX
+                if sys.platform == "darwin":
+                    new_filename = unicodedata.normalize("NFD", new_filename)
         return os.path.realpath(os.path.join(new_dirname, new_filename + ext.lower()))
 
     def _rename(self, old_filename, metadata, settings):
@@ -323,18 +321,21 @@ class File(LockableObject, Item):
             self.log.debug("Removing %r from %r", self, self.parent)
             self.parent.remove_file(self)
         self.tagger.puidmanager.remove(self.metadata['musicip_puid'])
+        self.tagger.acoustidmanager.remove(self)
         self.state = File.REMOVED
 
     def move(self, parent):
         if parent != self.parent:
             self.log.debug("Moving %r from %r to %r", self, self.parent, parent)
             self.clear_lookup_task()
+            self.tagger._ofa.stop_analyze(self)
             if self.parent:
                 self.clear_pending()
                 self.parent.remove_file(self)
             self.parent = parent
             self.parent.add_file(self)
             self.tagger.puidmanager.update(self.metadata['musicip_puid'], self.metadata['musicbrainz_trackid'])
+            self.tagger.acoustidmanager.update(self, self.metadata['musicbrainz_trackid'])
 
     def _move(self, parent):
         if parent != self.parent:
@@ -343,6 +344,7 @@ class File(LockableObject, Item):
                 self.parent.remove_file(self)
             self.parent = parent
             self.tagger.puidmanager.update(self.metadata['musicip_puid'], self.metadata['musicbrainz_trackid'])
+            self.tagger.acoustidmanager.update(self, self.metadata['musicbrainz_trackid'])
 
     def supports_tag(self, name):
         """Returns whether tag ``name`` can be saved to the file."""
@@ -425,14 +427,13 @@ class File(LockableObject, Item):
     state = property(get_state, set_state)
 
     def column(self, column):
-        if self.orig_metadata:
-            md = self.orig_metadata
-        else:
-            md = self.metadata
+        m = self.metadata
         if column == '~length':
-            return format_time(md.length), self.similarity
+            return format_time(m.length), self.similarity
+        elif column == "title" and not m["title"]:
+            return self.base_filename, self.similarity
         else:
-            return md[column], self.similarity
+            return m[column], self.similarity
 
     def _compare_to_track(self, track):
         """
@@ -500,6 +501,8 @@ class File(LockableObject, Item):
                 tracks = m.recording_list[0].recording
             elif lookuptype == "puid":
                 tracks = m.puid[0].recording_list[0].recording
+            elif lookuptype == "acoustid":
+                tracks = m.puid[0].recording_list[0].recording
             elif lookuptype == "trackid":
                 tracks = m.recording
         except (AttributeError, IndexError):
@@ -519,7 +522,7 @@ class File(LockableObject, Item):
         matches.sort(reverse=True)
         #self.log.debug("Track matches: %r", matches)
 
-        if lookuptype != 'puid':
+        if lookuptype != 'puid' and lookuptype != 'acoustid':
             threshold = self.config.setting['file_lookup_threshold']
             if matches[0][0] < threshold:
                 self.tagger.window.set_statusbar_message(N_("No matching tracks above the threshold for file %s"), self.filename, timeout=3000)
@@ -532,6 +535,8 @@ class File(LockableObject, Item):
         track = matches[0][1]
         if lookuptype == 'puid':
             self.tagger.puidmanager.add(self.metadata['musicip_puid'], track.id)
+        elif lookuptype == 'acoustid':
+            self.tagger.acoustidmanager.add(self, track.id)
         if albumid:
             self.tagger.move_file_to_track(self, albumid, track.id)
         else:
