@@ -21,6 +21,7 @@ from PyQt4 import QtCore, QtGui
 from picard.config import BoolOption, TextOption
 from picard.ui.options import OptionsPage, OptionsCheckError, register_options_page
 from picard.ui.ui_options_metadata import Ui_MetadataOptionsPage
+from picard.const import ALIAS_LOCALES
 
 
 class MetadataOptionsPage(OptionsPage):
@@ -34,13 +35,12 @@ class MetadataOptionsPage(OptionsPage):
     options = [
         TextOption("setting", "va_name", u"Various Artists"),
         TextOption("setting", "nat_name", u"[non-album tracks]"),
+        TextOption("setting", "artist_locale", u"en"),
         BoolOption("setting", "translate_artist_names", False),
         BoolOption("setting", "release_ars", True),
         BoolOption("setting", "track_ars", False),
         BoolOption("setting", "folksonomy_tags", False),
-        BoolOption("setting", "convert_punctuation", False),
-        BoolOption("setting", "standardize_tracks", False),
-        BoolOption("setting", "standardize_releases", False),
+        BoolOption("setting", "convert_punctuation", True),
         BoolOption("setting", "standardize_artists", False),
     ]
 
@@ -53,26 +53,35 @@ class MetadataOptionsPage(OptionsPage):
 
     def load(self):
         self.ui.translate_artist_names.setChecked(self.config.setting["translate_artist_names"])
+
+        combo_box = self.ui.artist_locale
+        locales = ALIAS_LOCALES.keys()
+        locales.sort()
+        for i, loc in enumerate(locales):
+            name = ALIAS_LOCALES[loc]
+            if "_" in loc:
+                name = "    " + name
+            combo_box.addItem(name, loc)
+            if loc == self.config.setting["artist_locale"]:
+                combo_box.setCurrentIndex(i)
+
         self.ui.convert_punctuation.setChecked(self.config.setting["convert_punctuation"])
         self.ui.release_ars.setChecked(self.config.setting["release_ars"])
         self.ui.track_ars.setChecked(self.config.setting["track_ars"])
         self.ui.folksonomy_tags.setChecked(self.config.setting["folksonomy_tags"])
         self.ui.va_name.setText(self.config.setting["va_name"])
         self.ui.nat_name.setText(self.config.setting["nat_name"])
-        self.ui.standardize_tracks.setChecked(self.config.setting["standardize_tracks"])
-        self.ui.standardize_releases.setChecked(self.config.setting["standardize_releases"])
         self.ui.standardize_artists.setChecked(self.config.setting["standardize_artists"])
 
     def save(self):
         self.config.setting["translate_artist_names"] = self.ui.translate_artist_names.isChecked()
+        self.config.setting["artist_locale"] = self.ui.artist_locale.itemData(self.ui.artist_locale.currentIndex())
         self.config.setting["convert_punctuation"] = self.ui.convert_punctuation.isChecked()
         self.config.setting["release_ars"] = self.ui.release_ars.isChecked()
         self.config.setting["track_ars"] = self.ui.track_ars.isChecked()
         self.config.setting["folksonomy_tags"] = self.ui.folksonomy_tags.isChecked()
         self.config.setting["va_name"] = self.ui.va_name.text()
         self.config.setting["nat_name"] = self.ui.nat_name.text()
-        self.config.setting["standardize_tracks"] = self.ui.standardize_tracks.isChecked()
-        self.config.setting["standardize_releases"] = self.ui.standardize_releases.isChecked()
         self.config.setting["standardize_artists"] = self.ui.standardize_artists.isChecked()
 
     def set_va_name_default(self):
